




___

Data Specification for the Teddy Bear Drop Foot Clinical Trial
___

# foo Create Data Specification

## Data Specification


Data Specification for the Teddy Bear Drop Foot Clinical Trial
>woof
##  Description
>Meow - 

Principle data requirements for Teddy Bear Drop Foot Clinical Trial.




# foo Create Data Dictionary
## Name
Clinical Trial Data Dictionary

## Description
A data dictionary for clinical trial data elements.




___


___

TBDF-Incoming Weekly Measurement Data
___

#  Update Data Structure

## Data Structure

TBDF-Incoming Weekly Measurement Data

## Description
This describes the weekly measurement data for each patient for the Teddy Bear drop foot clinical trial

## In Data Specification
Data Specification for the Teddy Bear Drop Foot Clinical Trial


## Qualified Name


___

WWT-Incoming Weekly Measurement Data

# foo Create Data Structure

## Qualified Name
DataStruct::WWT-Incoming Weekly Measurement Data

## GUID
ae221834-a3a6-4f32-ac94-110dff761b49

## Data Structure

WWT-Incoming Weekly Measurement Data


##  Description
A collection of data fields that form a data structure.


##  In Data Specification



##  Qualified Name

